@@ -55,7 +55,7 @@ import ast
 import datetime
 import importlib.abc
 import importlib.util
-from inspect import getinnerframes, getouterframes
+from inspect import getinnerframes, getouterframes, getsourcefile
 import logging
 import logging.config as logging_config
 import os
@@ -70,7 +70,7 @@ import weakref
 from ae.base import DATE_ISO, DATE_TIME_ISO                                         # type: ignore
 
 
-__version__ = '0.1.6'
+__version__ = '0.1.7'
 
 
 # suppress unused import err (needed e.g. for unpickling of dates via try_eval() and for include them into base_globals)
@@ -179,6 +179,24 @@ def module_callable(entry_point: str, module_path: str = "") -> Tuple[Optional[M
     return module, func
 
 
+def module_file_path(local_function: Optional[Callable] = None) -> str:
+    """ determine the absolute path of the module from which this function get called.
+
+    :param local_function:      optional local function of the calling module (passing `lambda: 0` also works).
+                                If omitted then the __file__ module variable will be used if the
+                                app module is frozen (by py2exe/PyInstaller).
+    :return:                    module path (inclusive module file name).
+    """
+    if local_function:
+        file_path = getsourcefile(local_function)
+        if file_path:
+            return os.path.abspath(file_path)
+
+    # if getattr(sys, 'frozen', False):
+    #    path_without_file = os.getcwd()
+    return stack_var('__file__', depth=3) or ""   # or use sys._getframe().f_code.co_filename
+
+
 def module_name(*skip_modules: str, depth: int = 1) -> Optional[str]:
     """ find the first module in the call stack that is *not* in :paramref:`module_name.skip_modules`.
 
